--require "camera"
require "player"
require "gun"
require "SpriteAnimation"

function maskedPixel(x, y, image)
	local r, g, b, a = imageData:getPixel( x, y )
	if a == 0 then
		return false
	else
		return true
	end
end

function maskedHLine(x, y, length, image)
	for i = 1, length do
		local r, g, b, a = imageData:getPixel( x + i, y )
		if a > 0 then
			return true
		end
	end
	return false
end

function maskedVLine(x, y, length, image)
	for i = 1, length do
		local r, g, b, a = imageData:getPixel( x, y + i )
		if a > 0 then
			return true
		end
	end
	return false
end


function love.load()
	success = love.graphics.setMode(640, 480, false, true, 0)
	love.graphics.setCaption( "Dollar Engine" )
	love.graphics.setBackgroundColor(51, 51, 51)
	width = love.graphics.getWidth()
	height = love.graphics.getHeight()
	bgm = love.audio.newSource("snd/Neve.s3m")
	bgm:setLooping(true)
	love.audio.play(bgm)
	
	imageData = love.image.newImageData( "img/map.png" )
	
	--load map
	map = love.graphics.newImage("img/map.png")
    
    --restrict camera
  --  camera:setBounds(0, 0, map.width * map.tileWidth - width, map.height * map.tileHeight - height)
	
	player.load()
	gun.load()
end

function love.update(dt)
	if love.keyboard.isDown('left') and not love.keyboard.isDown('right') then
		player.moveLeft(dt)
	end
	
	if love.keyboard.isDown('right') and not love.keyboard.isDown('left') then
		player.moveRight(dt)
	end
	
	if love.keyboard.isDown('rshift') then
		player.jump(dt)
	end
	
	if love.keyboard.isDown('rctrl') then
		player.holdShoot(dt)
	end
	
	bullets0.update(dt)
	bullets1.update(dt)
	bullets2.update(dt)
	bullets3.update(dt)
	shootEffect.update(dt)
	bDest.update(dt)
	player.update(dt)
	gun.update(dt)
	
--	camera:setPosition(math.floor(player.x - width / 2), math.floor(player.y - height / 2))
end

function love.keypressed(key)
	if key == "rctrl" then
		player.shoot()
	end
	
	if key == "escape" then
		love.event.push("quit")
	end
	
	gun.keypressed(key)
end

function love.keyreleased(key)
	if (key == "right") or (key == "left") then
        player.stop()
    end
	
	if key == "rshift" then
		player.jumpEnd()
	end
end

function love.draw()
--	camera:set()
	
	-- round x and y
	local x, y = math.floor(player.x), math.floor(player.y)
	
	love.graphics.draw(map, 1, 1)
	
	player.draw()
--	camera:unset()
	
	bullets0.draw()
	bullets1.draw()
	bullets2.draw()
	bullets3.draw()
	gun.draw()
	shootEffect.draw()
	bDest.draw()
end